BumpAllocator

Struct BumpAllocator 

pub struct BumpAllocator { /* private fields */ }
Bump allocator managing Regions and handing out TLABs.

Implementations

Source

impl BumpAllocator

pub fn new() -> Self

Create a new allocator (no regions pre-allocated).

pub fn alloc(&self, layout: Layout) -> *mut u8

Allocate memory for an object with the given layout.

Returns a pointer to the object data (after the GcHeader). The GcHeader is written automatically.

pub fn flush_tlab_for_sweep(&self)

Public TLAB flush for use by the incremental sweep path in GcHeap.

pub fn sweep(&self, _marker: &Marker) -> usize

Sweep all regions: walk objects, reclaim white objects. Returns total bytes collected.

pub fn total_region_bytes(&self) -> usize

Total bytes across all regions.

pub fn region_count(&self) -> usize

Number of regions.

pub fn regions(&self) -> &Vec<Region>

Get a reference to all regions (for the marker to iterate).

pub fn regions_mut(&self) -> &mut Vec<Region>

Get a mutable reference to all regions.