Module fixup

Module fixup 

Pointer fixup after relocation.

After objects are relocated and the forwarding table is populated, we must update all pointers (in live objects and root set) to point to the new locations.

Functions

fixup_nanboxed_bits
Fix up a NaN-boxed u64 value in-place if it contains a forwarded heap pointer.
fixup_ptr
Fix up a single raw pointer if it has a forwarding entry.
fixup_region
Fix up pointers within all live objects in a region.
fixup_roots
Fix up all pointers in the root set using the forwarding table.