pub unsafe fn set_active_forwarding(table: *mut ForwardingTable)Expand description
Set the active forwarding table for the trap handler to use.
Safety
The forwarding table must outlive the trap handler’s use of it.
pub unsafe fn set_active_forwarding(table: *mut ForwardingTable)Set the active forwarding table for the trap handler to use.
The forwarding table must outlive the trap handler’s use of it.